@@ -170,9 +170,10 @@ MagickPrivate SignatureInfo *AcquireSignatureInfo(void)
 */
 MagickPrivate SignatureInfo *DestroySignatureInfo(SignatureInfo *signature_info)
 {
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(signature_info != (SignatureInfo *) NULL);
   assert(signature_info->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   if (signature_info->accumulator != (unsigned int *) NULL)
     signature_info->accumulator=(unsigned int *) RelinquishMagickMemory(
       signature_info->accumulator);
@@ -231,9 +232,10 @@ MagickPrivate void FinalizeSignature(SignatureInfo *signature_info)
   /*
     Add padding and return the message accumulator.
   */
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(signature_info != (SignatureInfo *) NULL);
   assert(signature_info->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   low_order=signature_info->low_order;
   high_order=signature_info->high_order;
   extent=((low_order >> 3) & 0x3f);
@@ -296,9 +298,10 @@ MagickPrivate void FinalizeSignature(SignatureInfo *signature_info)
 MagickPrivate unsigned int GetSignatureBlocksize(
   const SignatureInfo *signature_info)
 {
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(signature_info != (SignatureInfo *) NULL);
   assert(signature_info->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   return(signature_info->blocksize);
 }
 
@@ -327,9 +330,10 @@ MagickPrivate unsigned int GetSignatureBlocksize(
 MagickPrivate const StringInfo *GetSignatureDigest(
   const SignatureInfo *signature_info)
 {
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(signature_info != (SignatureInfo *) NULL);
   assert(signature_info->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   return(signature_info->digest);
 }
 
@@ -358,9 +362,10 @@ MagickPrivate const StringInfo *GetSignatureDigest(
 MagickPrivate unsigned int GetSignatureDigestsize(
   const SignatureInfo *signature_info)
 {
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(signature_info != (SignatureInfo *) NULL);
   assert(signature_info->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   return(signature_info->digestsize);
 }
 
@@ -388,9 +393,10 @@ MagickPrivate unsigned int GetSignatureDigestsize(
 */
 MagickPrivate void InitializeSignature(SignatureInfo *signature_info)
 {
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(signature_info != (SignatureInfo *) NULL);
   assert(signature_info->signature == MagickCoreSignature);
+  if (IsEventLogging() != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   signature_info->accumulator[0]=0x6a09e667U;
   signature_info->accumulator[1]=0xbb67ae85U;
   signature_info->accumulator[2]=0x3c6ef372U;
@@ -499,7 +505,7 @@ MagickExport MagickBooleanType SignatureImage(Image *image,
   */
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
-  if (image->debug != MagickFalse)
+  if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   signature_info=AcquireSignatureInfo();
   signature=AcquireStringInfo(GetPixelChannels(image)*image->columns*
